diff src/prpl.h @ 10447:6feef0a9098a

[gaim-migrate @ 11712] A few minor improvements and some documentation updates. Conscious evolution in the back of your mind... committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Wed, 29 Dec 2004 21:53:59 +0000
parents 6a043ae92db6
children 94fd0bf8c4b1
line wrap: on
line diff
--- a/src/prpl.h	Wed Dec 29 20:01:48 2004 +0000
+++ b/src/prpl.h	Wed Dec 29 21:53:59 2004 +0000
@@ -414,11 +414,14 @@
 /**
  * Informs the server that an account's status changed.
  *
  * @param account The account the user is on.
  * @param status  The status that was activated, or deactivated
  *                (in the case of independent statuses).
  */
-void gaim_prpl_set_account_status(GaimAccount *account, GaimStatus *status);
+void gaim_prpl_change_account_status(GaimAccount *account,
+									 GaimStatus *old_status,
+									 GaimStatus *new_status);
 
 /**
  * Retrieves the list of stock status types from a prpl.
@@ -414,11 +414,14 @@
  * Informs the server that an account's status changed.
  *
- * @param account The account the user is on.
- * @param status  The status that was activated, or deactivated
- *                (in the case of independent statuses).
+ * @param account    The account the user is on.
+ * @param old_status The previous status.
+ * @param new_status The status that was activated, or deactivated
+ *                   (in the case of independent statuses).
  */